@@ -74,6 +74,9 @@ class Core:
         self.sdk_settings = sdk_settings
         rox_options = device_properties.rox_options
         self.rox_options = rox_options
+        if self.rox_options.hosting is not None:
+            Environment.SWITCH_TO_REGION_HOSTING(self.rox_options.hosting)
+
         roxy_path = rox_options.roxy_url if rox_options is not None and rox_options.roxy_url is not None else None
 
         if roxy_path is None:
@@ -106,7 +109,7 @@ class Core:
 
         if rox_options.is_self_managed():
             self.configuration_fetcher = ConfigurationFetcherSelfManaged(device_properties, client_request, self.configuration_fetched_invoker, self.error_reporter, buid)
-            self.state_sender = StateSender(device_properties, client_request_for_state, self.flag_repository, self.custom_property_repository, self.error_reporter, self.cancel_token)
+            self.state_sender = StateSender(device_properties, client_request_for_state, self.flag_repository, self.custom_property_repository, self.error_reporter)
         elif roxy_path is not None:
             self.configuration_fetcher = ConfigurationFetcherRoxy(device_properties, client_request, self.configuration_fetched_invoker, self.error_reporter, roxy_path)
         else:
